/*
 * file HelloWorld.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM - you are allowed to copy, modify and 
 * redistribute this file as part of any program that interfaces with 
 * IBM Rational CM API.
 *
 * com.ibm.rational.stp.client.samples.HelloWorld
 *
 *  Copyright IBM Corporation 2005, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */
package com.ibm.rational.stp.client.samples;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.swing.JOptionPane;
import javax.wvcm.ProviderFactory;

import com.ibm.rational.wvcm.stp.StpException;
import com.ibm.rational.wvcm.stp.StpProvider;
import com.ibm.rational.wvcm.stp.StpProvider.Domain;

/**
 * Instantiates a CM API provider and reports what's installed and what's not
 */
public class HelloWorld {
    public static void main(String[] args) throws Exception {
        boolean debug = args.length > 0 && args[0].equals("-debug");
        StpProvider provider = (StpProvider) ProviderFactory
            .createProvider(StpProvider.PROVIDER_CLASS, null);
        ArrayList<String> about = new ArrayList<String>();
        
        about.add(provider.getClass().getName() + ", version " 
            + provider.getClass().getPackage().getImplementationVersion());

        // Identify which repository types have providers at this time
        int failures = 0;
        Map<Object, StpException> errors = provider.getInstantiationErrors();
        
        for (Domain type: Domain.values()) {
            if (type != Domain.NONE && type != Domain.INVALID) {
                StpException error = errors.get(type);
                
                if (error == null) {
                    about.add("    " + type.toString() + " -- OK"); 
                } else {
                    ++failures;
                    about.add("    " + type.toString() + " -- " + error.toString());
    
                    if (debug)
                        error.printStackTrace();
                }
            }
        }
     
        List<String> seen = new ArrayList<String>();
        
        for (Package myPackage: Package.getPackages()) {
            String title = myPackage.getImplementationTitle();
            
            if (title != null && title.length() > 0 
                && (debug || !seen.contains(title))) {
                if (debug)
                    about.add(myPackage.getName());
                
                about.add("  " + myPackage.getImplementationTitle()
                    + ", " + myPackage.getImplementationVersion());
                seen.add(title);
            }
        }

        JOptionPane.showMessageDialog(null, about.toArray(), "About CM API", 
                                      JOptionPane.INFORMATION_MESSAGE);
        System.exit(failures);
    }
}
