/*
 * file InstallCheck.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM - you are allowed to copy, modify and 
 * redistribute this file as part of any program that interfaces with 
 * IBM Rational CM API.
 *
 * com.ibm.rational.stp.client.samples.InstallCheck
 *
 *  Copyright IBM Corporation 2005, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */
package com.ibm.rational.stp.client.samples;

import javax.wvcm.ProviderFactory;

import com.ibm.rational.wvcm.stp.StpProvider;
import com.ibm.rational.wvcm.stp.cq.CqProvider;

/**
 * An application for testing proper installation of the CM API library for a
 * specific repository type or types
 */
public class InstallCheck {
    /**
     * Instantiates a provider and tests for successful instantiation of
     * the repository types specified on the input command line.
     * @param args The Selector symbols for the repository type(s) to be tested.
     */
    public static void main(String[] args)
    {
        int errors = 0;

        try {
            StpProvider provider = (StpProvider) ProviderFactory
                .createProvider(StpProvider.PROVIDER_CLASS, null);
            Package[] packages = Package.getPackages();
            
            for (int i = 0; i < args.length; ++i) {
                StpProvider.Domain type = StpProvider.Domain.fromSymbol(args[i]);
                Exception error = 
                    (Exception)provider.getInstantiationErrors().get(type);
    
                if (error != null) {
                    ++errors;
                    error.printStackTrace();
                } else {
                    for (int j = 0; j < packages.length; ++j) {
                        Package myPackage = packages[j];
                        String name = myPackage.getName();
                        
                        if (name.indexOf("." + args[i]) >= 0
                            && !name.startsWith("com.ibm.rational.wvcm")) {
                            System.out.println(
                                "Instantiated " + name
                                + "  " + myPackage.getImplementationTitle()
                                + ", " + myPackage.getImplementationVersion()
                                + ", " + myPackage.getImplementationVendor());
                        }
                    }
                }
            }
        } catch (Throwable t) {
            errors = 100;
            t.printStackTrace();
        }
        
        System.exit(errors);
    }
}
