/*
 * file CreateActivityDemo.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM - you are allowed to copy, modify and 
 * redistribute this file as part of any program that interfaces with 
 * IBM Rational CM API.
 *
 * com.ibm.rational.stp.client.samples.CreateActivityDemo
 *
 *  Copyright IBM Corporation 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.stp.client.samples.cc;

import java.util.Date;

import javax.wvcm.PropertyRequestItem.PropertyRequest;

import com.ibm.rational.wvcm.stp.StpLocation;
import com.ibm.rational.wvcm.stp.StpLocation.Namespace;
import com.ibm.rational.wvcm.stp.StpProvider.Domain;
import com.ibm.rational.wvcm.stp.cc.CcActivity;
import com.ibm.rational.wvcm.stp.cc.CcProvider;
import com.ibm.rational.wvcm.stp.cc.CcStream;

/**
 * Create a new UCM activity in an existing UCM development stream.
 * Demonstrates WVCM's resource creation convention.
 * Also demonstrates how to construct resource locations and proxies.
 * as well as setting property values via "setter" methods.
 */
public class CreateActivityDemo extends CcDemoBase {

    /**
     * Create a new UCM activity in the development stream.
     */
    public void testMakeActivity() throws Exception {

        UcmHelper ucmHelper = new UcmHelper(this);
        CcProvider provider = getClearCaseProvider();

        // Get the development stream in which we'll create the new activity.
        CcStream devStream = ucmHelper.getUcmDevelopmentStream();

        // Create a location for the new activity.
        String pvobName = props().getDemoUcmProjectVob();
        StpLocation newActLoc = provider.userFriendlySelector(
                Domain.CLEAR_CASE,
                Namespace.ACTIVITY,
                "",         // activity name is auto-generated; see below
                pvobName);

        // Create a proxy for the new activity from the above location
        // Note: This does *not* create the activity - that happens below.
        //       If we tried to use this proxy now, we would get a "NOT_FOUND" error.
        CcActivity newAct = provider.ccActivity(newActLoc);

        // Set the properties we want this activity to have when it's created.
        newAct.setStream(devStream);
        newAct.setHeadline("This is a new activity: " + new Date());

        // The properties of the new activity we're interested in.
        PropertyRequest wantedProps = new PropertyRequest(
                CcActivity.DISPLAY_NAME,
                CcActivity.HEADLINE,
                CcActivity.STREAM.nest(
                        CcStream.DISPLAY_NAME
                ));

        // Now ask the server to actually create the activity.
        // Note that "doCreateGeneratedCcActivity()" automatically generates
        //     a unique name for the new activity so we don't have to.
        // Note also that we're making a property request at the same time
        //     we're creating the activity.  This saves an extra round-trip
        //     to the server and simplifies our code a bit.
        // Extra credit question: What is the purpose of the "newAct = " piece
        //     of this statement?
        newAct = newAct.doCreateGeneratedCcActivity(wantedProps);

        // Print new activity's properties
        trace("New activity name:          " + newAct.getDisplayName());
        trace("New activity headline:      " + newAct.getHeadline());
        trace("New activity parent stream: " + newAct.getStream().getDisplayName());
    }
}
