/*
 * file ScoutPlugin.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM - you are allowed to copy, modify and 
 * redistribute this file as part of any program that interfaces with 
 * IBM Rational CM API.
 *
 * com.ibm.rational.teamapi.scout.ScoutPlugin
 *
 *  Copyright IBM Corporation 2004, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */
package com.ibm.rational.teamapi.scout;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;

/**
 * The main plugin class to be used in the Eclipse desktop.
 */
public class ScoutPlugin extends AbstractUIPlugin {
	//The shared instance.
	private static ScoutPlugin plugin;
	//Resource bundle.
	private ResourceBundle resourceBundle;
	
	/**
	 * The constructor.
	 */
	public ScoutPlugin() {
		super();
		plugin = this;
		try {
			resourceBundle = ResourceBundle
                .getBundle("com.ibm.rational.teamapi.scout.ScoutPluginResources");
		} catch (MissingResourceException x) {
			resourceBundle = null;
		}
	}

	/**
	 * Returns the shared instance.
	 */
	public static ScoutPlugin getDefault() {
		return plugin;
	}

    /**
     * Returns the workspace instance.
     */
    public static IWorkspace getWorkspace() {
        return ResourcesPlugin.getWorkspace();
    }

	/**
	 * Returns the string from the plugin's resource bundle,
	 * or 'key' if not found.
	 */
	public static String getResourceString(String key) {
		ResourceBundle bundle = ScoutPlugin.getDefault().getResourceBundle();
		try {
			return (bundle != null) ? bundle.getString(key) : key;
		} catch (MissingResourceException e) {
			return key;
		}
	}

	/**
	 * Returns the plugin's resource bundle,
	 */
	public ResourceBundle getResourceBundle() {
		return resourceBundle;
	}

    /**
     * Returns the image descriptor for a named icon.
     * @param name The simple file name for the icon; e.g. "foldergif"
     * @return An ImageDescriptor for the icon; will not be null, but may be
     * the descriptor for the "missing image" if the requested icon is not found. 
     */
    public static ImageDescriptor getImageDescriptor(String name) {
        ImageDescriptor result = 
            imageDescriptorFromPlugin("com.ibm.rational.teamapi.scout", 
                                      "icons/"+name);
        
        if (result == null)
            result = ImageDescriptor.getMissingImageDescriptor();
        
        return result;
    }
}
