/*
 * file About.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM - you are allowed to copy, modify and 
 * redistribute this file as part of any program that interfaces with 
 * IBM Rational CM API.
 *
 * com.ibm.rational.teamapi.scout.actions.About
 *
 *  Copyright IBM Corporation 2004, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */
package com.ibm.rational.teamapi.scout.actions;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;

import javax.wvcm.ProviderFactory;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;

import com.ibm.rational.wvcm.stpex.StpExEnumerationBase;
import com.ibm.rational.wvcm.stp.StpException;
import com.ibm.rational.wvcm.stp.StpProvider;


/**
 * An IWorkbenchWindowActionDelegate that tests the ability to instantiate a 
 * CM API provider.
 *
 * @see  IWorkbenchWindowActionDelegate
 */
public class About
    implements IWorkbenchWindowActionDelegate
{
    /** The handle on the About box handle */
    private IWorkbenchWindow m_window;

    /**
     * Attempt to instantiate a CM API provider and report the results in a
     * dialog box.
     *
     * @see  IWorkbenchWindowActionDelegate#run
     */
    public void run(IAction action)
    {
        boolean   debug = false;
        ArrayList<String> about = new ArrayList<String>();

        try {
            String providerName = StpProvider.PROVIDER_CLASS;
            StpProvider provider =
                (StpProvider)ProviderFactory.createProvider(
                    providerName,
                    null);

            about.add("Using " + provider.getClass().getName() + ", version "
                + provider.getClass().getPackage().getImplementationVersion());

            Package[] packages = Package.getPackages();

            if (packages != null) {
                for (int i = 0; i < packages.length; ++i) {
                    Package myPackage = packages[i];

                    if (
                        myPackage.getName().startsWith(
                                "com.ibm.rational.wvcm.stp")
                            || myPackage.getName().startsWith("javax.wvcm")) {
                        about.add(myPackage.getName());
                        about.add("  " + myPackage.getSpecificationTitle()
                            + ", " + myPackage.getSpecificationVersion() + ", "
                            + myPackage.getSpecificationVendor());

                        about.add("");
                    }
                }
            }

            // Get the main interface package and display its name and version
            Package stpPackage =
                Package.getPackage("com.ibm.rational.wvcm.stp");

            if (stpPackage != null)
                about.add(stpPackage.getSpecificationTitle() + ", "
                    + stpPackage.getSpecificationVersion() + " for... ");

            // Identify which repository types have providers at this time
            Iterator types =
                StpExEnumerationBase.enumerator(StpProvider.Domain.class);
            Map      errors = provider.getInstantiationErrors();

            while (types.hasNext()) {
                StpProvider.Domain type = (StpProvider.Domain)types.next();

                if (!type.equals(StpProvider.Domain.NONE)
                        && !type.equals(StpProvider.Domain.INVALID)) {
                    StpException error = (StpException)errors.get(type);

                    about.add(type.toString() + " -- "
                        + (error == null ? "OK " : error.toString()));

                    if (debug && error != null)
                        error.printStackTrace();
                }
            }
        } catch (Throwable ex) {
            ex.printStackTrace();
            about.add(ex.getClass().getName() + ": "
                + ex.getLocalizedMessage());
        }

        StringBuffer msg = new StringBuffer();
        Iterator     iter = about.iterator();

        while (iter.hasNext()) {
            if (msg.length() > 0)
                msg.append("\n");

            msg.append(iter.next());
        }

        MessageDialog.openInformation(m_window.getShell(),
            "CM API Scout Plug-in",
            msg.toString());
    }

    /**
     * @see  IWorkbenchWindowActionDelegate#selectionChanged
     */
    public void selectionChanged(
        IAction    action,
        ISelection selection) {}

    /**
     * @see  IWorkbenchWindowActionDelegate#dispose
     */
    public void dispose() {}

    /**
     * @see  IWorkbenchWindowActionDelegate#init
     */
    public void init(IWorkbenchWindow window)
    {
        this.m_window = window;
    }
}
